Coverage for matplotlib\_version.py: 0%

# Coverage for matplotlib\_version.py : 0%

## 5 statements 0 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 | # This file was generated by 'versioneer.py' (0.15) from # revision-control system data, or from the parent directory name of an # unpacked source archive. Distribution tarballs contain a pre-generated copy # of this file. import json import sys version_json = ''' { "dirty": true, "error": null, "full-revisionid": "e87049972b3c88c8da09d807b339b64da960d879", "version": "2.2.2" } ''' # END VERSION_JSON def get_versions(): return json.loads(version_json)